# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/task_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/task_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/planning/proto/task_config.proto\x12\x0f\x61pollo.planning\"\xcc\x01\n\x12\x43reepDeciderConfig\x12\x1a\n\rstop_distance\x18\x01 \x01(\x01:\x03\x30.5\x12\x16\n\x0bspeed_limit\x18\x02 \x01(\x01:\x01\x31\x12$\n\x17max_valid_stop_distance\x18\x03 \x01(\x01:\x03\x30.3\x12\x19\n\x0emin_boundary_t\x18\x04 \x01(\x01:\x01\x36\x12 \n\x13ignore_max_st_min_t\x18\x05 \x01(\x01:\x03\x30.1\x12\x1f\n\x13ignore_min_st_min_s\x18\x06 \x01(\x01:\x02\x31\x35\"\x97\x02\n\x17LaneChangeDeciderConfig\x12(\n enable_lane_change_urgency_check\x18\x01 \x01(\x08\x12,\n\x1d\x65nable_prioritize_change_lane\x18\x02 \x01(\x08:\x05\x66\x61lse\x12(\n\x19\x65nable_remove_change_lane\x18\x03 \x01(\x08:\x05\x66\x61lse\x12#\n\x14reckless_change_lane\x18\x04 \x01(\x08:\x05\x66\x61lse\x12,\n\x1f\x63hange_lane_success_freeze_time\x18\x05 \x01(\x01:\x03\x31.5\x12\'\n\x1c\x63hange_lane_fail_freeze_time\x18\x06 \x01(\x01:\x01\x31\"\xde\x02\n LearningModelInferenceTaskConfig\x12O\n\nmodel_type\x18\x01 \x01(\x0e\x32;.apollo.planning.LearningModelInferenceTaskConfig.ModelType\x12\x16\n\x0e\x63pu_model_file\x18\x02 \x01(\t\x12\x16\n\x0egpu_model_file\x18\x03 \x01(\t\x12\x16\n\x08use_cuda\x18\x04 \x01(\x08:\x04true\x12\x1f\n\x12trajectory_delta_t\x18\x05 \x01(\x01:\x03\x30.2\x12.\n\x1f\x61llow_empty_learning_based_data\x18\x06 \x01(\x08:\x05\x66\x61lse\x12,\n\x1d\x61llow_empty_output_trajectory\x18\x07 \x01(\x08:\x05\x66\x61lse\"\"\n\tModelType\x12\x07\n\x03\x43NN\x10\x01\x12\x0c\n\x08\x43NN_LSTM\x10\x02\"^\n*LearningModelInferenceTrajectoryTaskConfig\x12\x30\n%min_adc_future_trajectory_time_length\x18\x01 \x01(\x01:\x01\x32\"\x88\x03\n\x19NaviObstacleDeciderConfig\x12\x1f\n\x12min_nudge_distance\x18\x01 \x01(\x01:\x03\x30.2\x12\x1f\n\x12max_nudge_distance\x18\x02 \x01(\x01:\x03\x31.2\x12%\n\x15max_allow_nudge_speed\x18\x03 \x01(\x01:\x06\x31\x36.667\x12\x1a\n\rsafe_distance\x18\x04 \x01(\x01:\x03\x30.2\x12#\n\x15nudge_allow_tolerance\x18\x05 \x01(\x01:\x04\x30.05\x12\x18\n\rcycles_number\x18\x06 \x01(\r:\x01\x33\x12\x1a\n\x0fjudge_dis_coeff\x18\x07 \x01(\x01:\x01\x32\x12\x1b\n\x0f\x62\x61sis_dis_value\x18\x08 \x01(\x01:\x02\x33\x30\x12#\n\x16lateral_velocity_value\x18\t \x01(\x01:\x03\x30.5\x12%\n\x1aspeed_decider_detect_range\x18\n \x01(\x01:\x01\x31\x12\"\n\x15max_keep_nudge_cycles\x18\x0b \x01(\r:\x03\x31\x30\x30\"\xd5\x03\n\x15NaviPathDeciderConfig\x12\x1a\n\x0fmin_path_length\x18\x01 \x01(\x01:\x01\x35\x12 \n\x15min_look_forward_time\x18\x02 \x01(\r:\x01\x32\x12#\n\x16max_keep_lane_distance\x18\x03 \x01(\x01:\x03\x30.8\x12!\n\x15max_keep_lane_shift_y\x18\x04 \x01(\x01:\x02\x32\x30\x12 \n\x14min_keep_lane_offset\x18\x05 \x01(\x01:\x02\x31\x35\x12*\n\x1ckeep_lane_shift_compensation\x18\x06 \x01(\x01:\x04\x30.01\x12M\n\x1bmove_dest_lane_config_talbe\x18\x07 \x01(\x0b\x32(.apollo.planning.MoveDestLaneConfigTable\x12)\n\x1bmove_dest_lane_compensation\x18\x08 \x01(\x01:\x04\x30.35\x12\x1e\n\x13max_kappa_threshold\x18\t \x01(\x01:\x01\x30\x12,\n!kappa_move_dest_lane_compensation\x18\n \x01(\x01:\x01\x30\x12 \n\x15start_plan_point_from\x18\x0b \x01(\r:\x01\x30\"N\n\x17MoveDestLaneConfigTable\x12\x33\n\rlateral_shift\x18\x01 \x03(\x0b\x32\x1c.apollo.planning.ShiftConfig\"O\n\x0bShiftConfig\x12\x17\n\tmax_speed\x18\x01 \x01(\x01:\x04\x34.16\x12\'\n\x1amax_move_dest_lane_shift_y\x18\x03 \x01(\x01:\x03\x30.4\"\xd2\x04\n\x16NaviSpeedDeciderConfig\x12\x1a\n\x0fpreferred_accel\x18\x01 \x01(\x01:\x01\x32\x12\x1a\n\x0fpreferred_decel\x18\x02 \x01(\x01:\x01\x32\x12\x19\n\x0epreferred_jerk\x18\x03 \x01(\x01:\x01\x32\x12\x14\n\tmax_accel\x18\x04 \x01(\x01:\x01\x34\x12\x14\n\tmax_decel\x18\x05 \x01(\x01:\x01\x35\x12\x1c\n\x0fobstacle_buffer\x18\x06 \x01(\x01:\x03\x30.5\x12\x1d\n\x12safe_distance_base\x18\x07 \x01(\x01:\x01\x32\x12\x1e\n\x13safe_distance_ratio\x18\x08 \x01(\x01:\x01\x31\x12\"\n\x15\x66ollowing_accel_ratio\x18\t \x01(\x01:\x03\x30.5\x12%\n\x18soft_centric_accel_limit\x18\n \x01(\x01:\x03\x31.2\x12%\n\x18hard_centric_accel_limit\x18\x0b \x01(\x01:\x03\x31.5\x12\x1d\n\x10hard_speed_limit\x18\x0c \x01(\x01:\x03\x31\x30\x30\x12\x1c\n\x10hard_accel_limit\x18\r \x01(\x01:\x02\x31\x30\x12\x1e\n\x10\x65nable_safe_path\x18\x0e \x01(\x08:\x04true\x12)\n\x1b\x65nable_planning_start_point\x18\x0f \x01(\x08:\x04true\x12,\n\x1e\x65nable_accel_auto_compensation\x18\x10 \x01(\x08:\x04true\x12\x18\n\rkappa_preview\x18\x11 \x01(\x01:\x01\x30\x12\x1a\n\x0fkappa_threshold\x18\x12 \x01(\x01:\x01\x30\"\x1d\n\x1bPathAssessmentDeciderConfig\"\xe7\x02\n\x17PathBoundsDeciderConfig\x12\x19\n\x11is_lane_borrowing\x18\x01 \x01(\x08\x12\x14\n\x0cis_pull_over\x18\x02 \x01(\x08\x12/\n#pull_over_destination_to_adc_buffer\x18\x03 \x01(\x01:\x02\x32\x35\x12\x33\n\'pull_over_destination_to_pathend_buffer\x18\x04 \x01(\x01:\x02\x31\x30\x12(\n\x1apull_over_road_edge_buffer\x18\x05 \x01(\x01:\x04\x30.15\x12:\n-pull_over_approach_lon_distance_adjust_factor\x18\x06 \x01(\x01:\x03\x31.5\x12\x1b\n\x10\x61\x64\x63_buffer_coeff\x18\x07 \x01(\x01:\x01\x31\x12\x32\n$is_extend_lane_bounds_to_include_adc\x18\x08 \x01(\x08:\x04true\"8\n\x11PathDeciderConfig\x12#\n\x16static_obstacle_buffer\x18\x01 \x01(\x01:\x03\x30.3\";\n\x1bPathLaneBorrowDeciderConfig\x12\x1c\n\x14\x61llow_lane_borrowing\x18\x01 \x01(\x08\"h\n\x1aPathReferenceDeciderConfig\x12%\n\x19min_path_reference_length\x18\x01 \x01(\r:\x02\x32\x30\x12#\n\x1bweight_x_ref_path_reference\x18\x02 \x01(\x01\",\n\x16PathReuseDeciderConfig\x12\x12\n\nreuse_path\x18\x01 \x01(\x08\"\xdd\x02\n*PiecewiseJerkNonlinearSpeedOptimizerConfig\x12\x17\n\nacc_weight\x18\x01 \x01(\x01:\x03\x35\x30\x30\x12\x18\n\x0bjerk_weight\x18\x02 \x01(\x01:\x03\x31\x30\x30\x12\x1b\n\x0elat_acc_weight\x18\x03 \x01(\x01:\x03\x35\x30\x30\x12\x1e\n\x12s_potential_weight\x18\x04 \x01(\x01:\x02\x31\x30\x12\x18\n\x0cref_v_weight\x18\x05 \x01(\x01:\x02\x31\x30\x12\x18\n\x0cref_s_weight\x18\x06 \x01(\x01:\x02\x31\x30\x12\x18\n\x0c\x65nd_s_weight\x18\x07 \x01(\x01:\x02\x31\x30\x12\x18\n\x0c\x65nd_v_weight\x18\x08 \x01(\x01:\x02\x31\x30\x12\x18\n\x0c\x65nd_a_weight\x18\t \x01(\x01:\x02\x31\x30\x12\x1f\n\x13soft_s_bound_weight\x18\n \x01(\x01:\x02\x31\x30\x12\x1c\n\x0euse_warm_start\x18\x64 \x01(\x08:\x04true\"\xda\x01\n PiecewiseJerkPathOptimizerConfig\x12\x46\n\x13\x64\x65\x66\x61ult_path_config\x18\x01 \x01(\x0b\x32).apollo.planning.PiecewiseJerkPathWeights\x12J\n\x17lane_change_path_config\x18\x02 \x01(\x0b\x32).apollo.planning.PiecewiseJerkPathWeights\x12\"\n\x17path_reference_l_weight\x18\x03 \x01(\x01:\x01\x30\"}\n\x18PiecewiseJerkPathWeights\x12\x13\n\x08l_weight\x18\x01 \x01(\x01:\x01\x31\x12\x16\n\tdl_weight\x18\x02 \x01(\x01:\x03\x31\x30\x30\x12\x18\n\nddl_weight\x18\x03 \x01(\x01:\x04\x31\x30\x30\x30\x12\x1a\n\x0b\x64\x64\x64l_weight\x18\x04 \x01(\x01:\x05\x31\x30\x30\x30\x30\"\xab\x01\n!PiecewiseJerkSpeedOptimizerConfig\x12\x15\n\nacc_weight\x18\x01 \x01(\x01:\x01\x31\x12\x17\n\x0bjerk_weight\x18\x02 \x01(\x01:\x02\x31\x30\x12\"\n\x14kappa_penalty_weight\x18\x03 \x01(\x01:\x04\x31\x30\x30\x30\x12\x18\n\x0cref_s_weight\x18\x04 \x01(\x01:\x02\x31\x30\x12\x18\n\x0cref_v_weight\x18\x05 \x01(\x01:\x02\x31\x30\"\xce\x02\n\x1aRuleBasedStopDeciderConfig\x12\x1f\n\x12max_adc_stop_speed\x18\x01 \x01(\x01:\x03\x30.3\x12$\n\x17max_valid_stop_distance\x18\x02 \x01(\x01:\x03\x30.5\x12\x1d\n\x12search_beam_length\x18\x03 \x01(\x01:\x01\x35\x12*\n\x1csearch_beam_radius_intensity\x18\x04 \x01(\x01:\x04\x30.08\x12\x1a\n\x0csearch_range\x18\x05 \x01(\x01:\x04\x33.14\x12&\n\x18is_block_angle_threshold\x18\x06 \x01(\x01:\x04\x31.57\x12-\n!approach_distance_for_lane_change\x18\n \x01(\x01:\x02\x38\x30\x12+\n\x1furgent_distance_for_lane_change\x18\x0b \x01(\x01:\x02\x35\x30\"\xbf\x02\n\x18SpeedBoundsDeciderConfig\x12\x15\n\ntotal_time\x18\x01 \x01(\x01:\x01\x37\x12\x1c\n\x0f\x62oundary_buffer\x18\x02 \x01(\x01:\x03\x30.1\x12)\n\x1emax_centric_acceleration_limit\x18\x03 \x01(\x01:\x01\x32\x12\x1c\n\rminimal_kappa\x18\x04 \x01(\x01:\x05\x31\x65-05\x12\x1a\n\x0fpoint_extension\x18\x05 \x01(\x01:\x01\x31\x12\x19\n\x0clowest_speed\x18\x06 \x01(\x01:\x03\x32.5\x12!\n\x16\x63ollision_safety_range\x18\x07 \x01(\x01:\x01\x31\x12$\n\x1cstatic_obs_nudge_speed_ratio\x18\x08 \x01(\x01\x12%\n\x1d\x64ynamic_obs_nudge_speed_ratio\x18\t \x01(\x01\"\xb5\x01\n\x1dSpeedHeuristicOptimizerConfig\x12G\n\x14\x64\x65\x66\x61ult_speed_config\x18\x01 \x01(\x0b\x32).apollo.planning.DpStSpeedOptimizerConfig\x12K\n\x18lane_change_speed_config\x18\x02 \x01(\x0b\x32).apollo.planning.DpStSpeedOptimizerConfig\"\xc9\x06\n\x18\x44pStSpeedOptimizerConfig\x12\x11\n\x06unit_t\x18\x01 \x01(\x01:\x01\x31\x12\x1d\n\x11\x64\x65nse_dimension_s\x18\x02 \x01(\x05:\x02\x34\x31\x12\x19\n\x0c\x64\x65nse_unit_s\x18\x03 \x01(\x01:\x03\x30.5\x12\x18\n\rsparse_unit_s\x18\x04 \x01(\x01:\x01\x31\x12\x17\n\x0cspeed_weight\x18\n \x01(\x01:\x01\x30\x12\x18\n\x0c\x61\x63\x63\x65l_weight\x18\x0b \x01(\x01:\x02\x31\x30\x12\x17\n\x0bjerk_weight\x18\x0c \x01(\x01:\x02\x31\x30\x12\x1a\n\x0fobstacle_weight\x18\r \x01(\x01:\x01\x31\x12\x1b\n\x10reference_weight\x18\x0e \x01(\x01:\x01\x30\x12\x19\n\x0ego_down_buffer\x18\x0f \x01(\x01:\x01\x35\x12\x17\n\x0cgo_up_buffer\x18\x10 \x01(\x01:\x01\x35\x12*\n\x15\x64\x65\x66\x61ult_obstacle_cost\x18\x14 \x01(\x01:\x0b\x31\x30\x30\x30\x30\x30\x30\x30\x30\x30\x30\x12\x1d\n\x12\x64\x65\x66\x61ult_speed_cost\x18\x1f \x01(\x01:\x01\x31\x12 \n\x14\x65xceed_speed_penalty\x18  \x01(\x01:\x02\x31\x30\x12\x1e\n\x11low_speed_penalty\x18! \x01(\x01:\x03\x32.5\x12\"\n\x17reference_speed_penalty\x18\" \x01(\x01:\x01\x31\x12(\n\x1ckeep_clear_low_speed_penalty\x18# \x01(\x01:\x02\x31\x30\x12\x18\n\raccel_penalty\x18( \x01(\x01:\x01\x32\x12\x18\n\rdecel_penalty\x18) \x01(\x01:\x01\x32\x12\x1e\n\x13positive_jerk_coeff\x18\x32 \x01(\x01:\x01\x31\x12 \n\x13negative_jerk_coeff\x18\x33 \x01(\x01:\x03\x33\x30\x30\x12\x1d\n\x10max_acceleration\x18< \x01(\x01:\x03\x34.5\x12\x1e\n\x10max_deceleration\x18= \x01(\x01:\x04-4.5\x12\x1b\n\x10safe_time_buffer\x18\x46 \x01(\x01:\x01\x33\x12\x19\n\rsafe_distance\x18G \x01(\x01:\x02\x32\x30\x12$\n\x19spatial_potential_penalty\x18P \x01(\x01:\x01\x31\x12\x1f\n\x10is_lane_changing\x18Q \x01(\x08:\x05\x66\x61lse\".\n\x15STBoundsDeciderConfig\x12\x15\n\ntotal_time\x18\x01 \x01(\x01:\x01\x37'
)



_LEARNINGMODELINFERENCETASKCONFIG_MODELTYPE = _descriptor.EnumDescriptor(
  name='ModelType',
  full_name='apollo.planning.LearningModelInferenceTaskConfig.ModelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CNN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CNN_LSTM', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=867,
  serialized_end=901,
)
_sym_db.RegisterEnumDescriptor(_LEARNINGMODELINFERENCETASKCONFIG_MODELTYPE)


_CREEPDECIDERCONFIG = _descriptor.Descriptor(
  name='CreepDeciderConfig',
  full_name='apollo.planning.CreepDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.CreepDeciderConfig.stop_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.planning.CreepDeciderConfig.speed_limit', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.CreepDeciderConfig.max_valid_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_boundary_t', full_name='apollo.planning.CreepDeciderConfig.min_boundary_t', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(6),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_max_st_min_t', full_name='apollo.planning.CreepDeciderConfig.ignore_max_st_min_t', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_min_st_min_s', full_name='apollo.planning.CreepDeciderConfig.ignore_min_st_min_s', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(15),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=266,
)


_LANECHANGEDECIDERCONFIG = _descriptor.Descriptor(
  name='LaneChangeDeciderConfig',
  full_name='apollo.planning.LaneChangeDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_lane_change_urgency_check', full_name='apollo.planning.LaneChangeDeciderConfig.enable_lane_change_urgency_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_prioritize_change_lane', full_name='apollo.planning.LaneChangeDeciderConfig.enable_prioritize_change_lane', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_remove_change_lane', full_name='apollo.planning.LaneChangeDeciderConfig.enable_remove_change_lane', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reckless_change_lane', full_name='apollo.planning.LaneChangeDeciderConfig.reckless_change_lane', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane_success_freeze_time', full_name='apollo.planning.LaneChangeDeciderConfig.change_lane_success_freeze_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane_fail_freeze_time', full_name='apollo.planning.LaneChangeDeciderConfig.change_lane_fail_freeze_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=548,
)


_LEARNINGMODELINFERENCETASKCONFIG = _descriptor.Descriptor(
  name='LearningModelInferenceTaskConfig',
  full_name='apollo.planning.LearningModelInferenceTaskConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_type', full_name='apollo.planning.LearningModelInferenceTaskConfig.model_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_model_file', full_name='apollo.planning.LearningModelInferenceTaskConfig.cpu_model_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_model_file', full_name='apollo.planning.LearningModelInferenceTaskConfig.gpu_model_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_cuda', full_name='apollo.planning.LearningModelInferenceTaskConfig.use_cuda', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_delta_t', full_name='apollo.planning.LearningModelInferenceTaskConfig.trajectory_delta_t', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_empty_learning_based_data', full_name='apollo.planning.LearningModelInferenceTaskConfig.allow_empty_learning_based_data', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_empty_output_trajectory', full_name='apollo.planning.LearningModelInferenceTaskConfig.allow_empty_output_trajectory', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEARNINGMODELINFERENCETASKCONFIG_MODELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=901,
)


_LEARNINGMODELINFERENCETRAJECTORYTASKCONFIG = _descriptor.Descriptor(
  name='LearningModelInferenceTrajectoryTaskConfig',
  full_name='apollo.planning.LearningModelInferenceTrajectoryTaskConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_adc_future_trajectory_time_length', full_name='apollo.planning.LearningModelInferenceTrajectoryTaskConfig.min_adc_future_trajectory_time_length', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=997,
)


_NAVIOBSTACLEDECIDERCONFIG = _descriptor.Descriptor(
  name='NaviObstacleDeciderConfig',
  full_name='apollo.planning.NaviObstacleDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_nudge_distance', full_name='apollo.planning.NaviObstacleDeciderConfig.min_nudge_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_nudge_distance', full_name='apollo.planning.NaviObstacleDeciderConfig.max_nudge_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_allow_nudge_speed', full_name='apollo.planning.NaviObstacleDeciderConfig.max_allow_nudge_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(16.667),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_distance', full_name='apollo.planning.NaviObstacleDeciderConfig.safe_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nudge_allow_tolerance', full_name='apollo.planning.NaviObstacleDeciderConfig.nudge_allow_tolerance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycles_number', full_name='apollo.planning.NaviObstacleDeciderConfig.cycles_number', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='judge_dis_coeff', full_name='apollo.planning.NaviObstacleDeciderConfig.judge_dis_coeff', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basis_dis_value', full_name='apollo.planning.NaviObstacleDeciderConfig.basis_dis_value', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(30),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_velocity_value', full_name='apollo.planning.NaviObstacleDeciderConfig.lateral_velocity_value', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_decider_detect_range', full_name='apollo.planning.NaviObstacleDeciderConfig.speed_decider_detect_range', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_keep_nudge_cycles', full_name='apollo.planning.NaviObstacleDeciderConfig.max_keep_nudge_cycles', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1392,
)


_NAVIPATHDECIDERCONFIG = _descriptor.Descriptor(
  name='NaviPathDeciderConfig',
  full_name='apollo.planning.NaviPathDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_path_length', full_name='apollo.planning.NaviPathDeciderConfig.min_path_length', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_look_forward_time', full_name='apollo.planning.NaviPathDeciderConfig.min_look_forward_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_keep_lane_distance', full_name='apollo.planning.NaviPathDeciderConfig.max_keep_lane_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_keep_lane_shift_y', full_name='apollo.planning.NaviPathDeciderConfig.max_keep_lane_shift_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(20),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_keep_lane_offset', full_name='apollo.planning.NaviPathDeciderConfig.min_keep_lane_offset', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(15),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_lane_shift_compensation', full_name='apollo.planning.NaviPathDeciderConfig.keep_lane_shift_compensation', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_dest_lane_config_talbe', full_name='apollo.planning.NaviPathDeciderConfig.move_dest_lane_config_talbe', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_dest_lane_compensation', full_name='apollo.planning.NaviPathDeciderConfig.move_dest_lane_compensation', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.35),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_kappa_threshold', full_name='apollo.planning.NaviPathDeciderConfig.max_kappa_threshold', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_move_dest_lane_compensation', full_name='apollo.planning.NaviPathDeciderConfig.kappa_move_dest_lane_compensation', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_plan_point_from', full_name='apollo.planning.NaviPathDeciderConfig.start_plan_point_from', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1864,
)


_MOVEDESTLANECONFIGTABLE = _descriptor.Descriptor(
  name='MoveDestLaneConfigTable',
  full_name='apollo.planning.MoveDestLaneConfigTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_shift', full_name='apollo.planning.MoveDestLaneConfigTable.lateral_shift', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=1944,
)


_SHIFTCONFIG = _descriptor.Descriptor(
  name='ShiftConfig',
  full_name='apollo.planning.ShiftConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_speed', full_name='apollo.planning.ShiftConfig.max_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4.16),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_move_dest_lane_shift_y', full_name='apollo.planning.ShiftConfig.max_move_dest_lane_shift_y', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=2025,
)


_NAVISPEEDDECIDERCONFIG = _descriptor.Descriptor(
  name='NaviSpeedDeciderConfig',
  full_name='apollo.planning.NaviSpeedDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferred_accel', full_name='apollo.planning.NaviSpeedDeciderConfig.preferred_accel', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_decel', full_name='apollo.planning.NaviSpeedDeciderConfig.preferred_decel', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_jerk', full_name='apollo.planning.NaviSpeedDeciderConfig.preferred_jerk', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_accel', full_name='apollo.planning.NaviSpeedDeciderConfig.max_accel', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_decel', full_name='apollo.planning.NaviSpeedDeciderConfig.max_decel', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_buffer', full_name='apollo.planning.NaviSpeedDeciderConfig.obstacle_buffer', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_distance_base', full_name='apollo.planning.NaviSpeedDeciderConfig.safe_distance_base', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_distance_ratio', full_name='apollo.planning.NaviSpeedDeciderConfig.safe_distance_ratio', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='following_accel_ratio', full_name='apollo.planning.NaviSpeedDeciderConfig.following_accel_ratio', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soft_centric_accel_limit', full_name='apollo.planning.NaviSpeedDeciderConfig.soft_centric_accel_limit', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hard_centric_accel_limit', full_name='apollo.planning.NaviSpeedDeciderConfig.hard_centric_accel_limit', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hard_speed_limit', full_name='apollo.planning.NaviSpeedDeciderConfig.hard_speed_limit', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hard_accel_limit', full_name='apollo.planning.NaviSpeedDeciderConfig.hard_accel_limit', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_safe_path', full_name='apollo.planning.NaviSpeedDeciderConfig.enable_safe_path', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_planning_start_point', full_name='apollo.planning.NaviSpeedDeciderConfig.enable_planning_start_point', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_accel_auto_compensation', full_name='apollo.planning.NaviSpeedDeciderConfig.enable_accel_auto_compensation', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_preview', full_name='apollo.planning.NaviSpeedDeciderConfig.kappa_preview', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_threshold', full_name='apollo.planning.NaviSpeedDeciderConfig.kappa_threshold', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2028,
  serialized_end=2622,
)


_PATHASSESSMENTDECIDERCONFIG = _descriptor.Descriptor(
  name='PathAssessmentDeciderConfig',
  full_name='apollo.planning.PathAssessmentDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2624,
  serialized_end=2653,
)


_PATHBOUNDSDECIDERCONFIG = _descriptor.Descriptor(
  name='PathBoundsDeciderConfig',
  full_name='apollo.planning.PathBoundsDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_lane_borrowing', full_name='apollo.planning.PathBoundsDeciderConfig.is_lane_borrowing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pull_over', full_name='apollo.planning.PathBoundsDeciderConfig.is_pull_over', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_destination_to_adc_buffer', full_name='apollo.planning.PathBoundsDeciderConfig.pull_over_destination_to_adc_buffer', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_destination_to_pathend_buffer', full_name='apollo.planning.PathBoundsDeciderConfig.pull_over_destination_to_pathend_buffer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_road_edge_buffer', full_name='apollo.planning.PathBoundsDeciderConfig.pull_over_road_edge_buffer', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.15),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_approach_lon_distance_adjust_factor', full_name='apollo.planning.PathBoundsDeciderConfig.pull_over_approach_lon_distance_adjust_factor', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_buffer_coeff', full_name='apollo.planning.PathBoundsDeciderConfig.adc_buffer_coeff', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_extend_lane_bounds_to_include_adc', full_name='apollo.planning.PathBoundsDeciderConfig.is_extend_lane_bounds_to_include_adc', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2656,
  serialized_end=3015,
)


_PATHDECIDERCONFIG = _descriptor.Descriptor(
  name='PathDeciderConfig',
  full_name='apollo.planning.PathDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_obstacle_buffer', full_name='apollo.planning.PathDeciderConfig.static_obstacle_buffer', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3017,
  serialized_end=3073,
)


_PATHLANEBORROWDECIDERCONFIG = _descriptor.Descriptor(
  name='PathLaneBorrowDeciderConfig',
  full_name='apollo.planning.PathLaneBorrowDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_lane_borrowing', full_name='apollo.planning.PathLaneBorrowDeciderConfig.allow_lane_borrowing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3075,
  serialized_end=3134,
)


_PATHREFERENCEDECIDERCONFIG = _descriptor.Descriptor(
  name='PathReferenceDeciderConfig',
  full_name='apollo.planning.PathReferenceDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_path_reference_length', full_name='apollo.planning.PathReferenceDeciderConfig.min_path_reference_length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_x_ref_path_reference', full_name='apollo.planning.PathReferenceDeciderConfig.weight_x_ref_path_reference', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3136,
  serialized_end=3240,
)


_PATHREUSEDECIDERCONFIG = _descriptor.Descriptor(
  name='PathReuseDeciderConfig',
  full_name='apollo.planning.PathReuseDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reuse_path', full_name='apollo.planning.PathReuseDeciderConfig.reuse_path', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3242,
  serialized_end=3286,
)


_PIECEWISEJERKNONLINEARSPEEDOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='PiecewiseJerkNonlinearSpeedOptimizerConfig',
  full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acc_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.acc_weight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(500),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.jerk_weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_acc_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.lat_acc_weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(500),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_potential_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.s_potential_weight', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_v_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.ref_v_weight', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_s_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.ref_s_weight', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.end_s_weight', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_v_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.end_v_weight', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_a_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.end_a_weight', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soft_s_bound_weight', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.soft_s_bound_weight', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_warm_start', full_name='apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig.use_warm_start', index=10,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3289,
  serialized_end=3638,
)


_PIECEWISEJERKPATHOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='PiecewiseJerkPathOptimizerConfig',
  full_name='apollo.planning.PiecewiseJerkPathOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_path_config', full_name='apollo.planning.PiecewiseJerkPathOptimizerConfig.default_path_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_change_path_config', full_name='apollo.planning.PiecewiseJerkPathOptimizerConfig.lane_change_path_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_reference_l_weight', full_name='apollo.planning.PiecewiseJerkPathOptimizerConfig.path_reference_l_weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3641,
  serialized_end=3859,
)


_PIECEWISEJERKPATHWEIGHTS = _descriptor.Descriptor(
  name='PiecewiseJerkPathWeights',
  full_name='apollo.planning.PiecewiseJerkPathWeights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='l_weight', full_name='apollo.planning.PiecewiseJerkPathWeights.l_weight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dl_weight', full_name='apollo.planning.PiecewiseJerkPathWeights.dl_weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ddl_weight', full_name='apollo.planning.PiecewiseJerkPathWeights.ddl_weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dddl_weight', full_name='apollo.planning.PiecewiseJerkPathWeights.dddl_weight', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3861,
  serialized_end=3986,
)


_PIECEWISEJERKSPEEDOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='PiecewiseJerkSpeedOptimizerConfig',
  full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acc_weight', full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig.acc_weight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_weight', full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig.jerk_weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa_penalty_weight', full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig.kappa_penalty_weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_s_weight', full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig.ref_s_weight', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_v_weight', full_name='apollo.planning.PiecewiseJerkSpeedOptimizerConfig.ref_v_weight', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3989,
  serialized_end=4160,
)


_RULEBASEDSTOPDECIDERCONFIG = _descriptor.Descriptor(
  name='RuleBasedStopDeciderConfig',
  full_name='apollo.planning.RuleBasedStopDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_adc_stop_speed', full_name='apollo.planning.RuleBasedStopDeciderConfig.max_adc_stop_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.RuleBasedStopDeciderConfig.max_valid_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_beam_length', full_name='apollo.planning.RuleBasedStopDeciderConfig.search_beam_length', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_beam_radius_intensity', full_name='apollo.planning.RuleBasedStopDeciderConfig.search_beam_radius_intensity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_range', full_name='apollo.planning.RuleBasedStopDeciderConfig.search_range', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3.14),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_block_angle_threshold', full_name='apollo.planning.RuleBasedStopDeciderConfig.is_block_angle_threshold', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.57),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approach_distance_for_lane_change', full_name='apollo.planning.RuleBasedStopDeciderConfig.approach_distance_for_lane_change', index=6,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(80),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urgent_distance_for_lane_change', full_name='apollo.planning.RuleBasedStopDeciderConfig.urgent_distance_for_lane_change', index=7,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(50),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4163,
  serialized_end=4497,
)


_SPEEDBOUNDSDECIDERCONFIG = _descriptor.Descriptor(
  name='SpeedBoundsDeciderConfig',
  full_name='apollo.planning.SpeedBoundsDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time', full_name='apollo.planning.SpeedBoundsDeciderConfig.total_time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary_buffer', full_name='apollo.planning.SpeedBoundsDeciderConfig.boundary_buffer', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_centric_acceleration_limit', full_name='apollo.planning.SpeedBoundsDeciderConfig.max_centric_acceleration_limit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimal_kappa', full_name='apollo.planning.SpeedBoundsDeciderConfig.minimal_kappa', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_extension', full_name='apollo.planning.SpeedBoundsDeciderConfig.point_extension', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowest_speed', full_name='apollo.planning.SpeedBoundsDeciderConfig.lowest_speed', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collision_safety_range', full_name='apollo.planning.SpeedBoundsDeciderConfig.collision_safety_range', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obs_nudge_speed_ratio', full_name='apollo.planning.SpeedBoundsDeciderConfig.static_obs_nudge_speed_ratio', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obs_nudge_speed_ratio', full_name='apollo.planning.SpeedBoundsDeciderConfig.dynamic_obs_nudge_speed_ratio', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4500,
  serialized_end=4819,
)


_SPEEDHEURISTICOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='SpeedHeuristicOptimizerConfig',
  full_name='apollo.planning.SpeedHeuristicOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_speed_config', full_name='apollo.planning.SpeedHeuristicOptimizerConfig.default_speed_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_change_speed_config', full_name='apollo.planning.SpeedHeuristicOptimizerConfig.lane_change_speed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4822,
  serialized_end=5003,
)


_DPSTSPEEDOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='DpStSpeedOptimizerConfig',
  full_name='apollo.planning.DpStSpeedOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_t', full_name='apollo.planning.DpStSpeedOptimizerConfig.unit_t', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dense_dimension_s', full_name='apollo.planning.DpStSpeedOptimizerConfig.dense_dimension_s', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=41,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dense_unit_s', full_name='apollo.planning.DpStSpeedOptimizerConfig.dense_unit_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparse_unit_s', full_name='apollo.planning.DpStSpeedOptimizerConfig.sparse_unit_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_weight', full_name='apollo.planning.DpStSpeedOptimizerConfig.speed_weight', index=4,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_weight', full_name='apollo.planning.DpStSpeedOptimizerConfig.accel_weight', index=5,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_weight', full_name='apollo.planning.DpStSpeedOptimizerConfig.jerk_weight', index=6,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_weight', full_name='apollo.planning.DpStSpeedOptimizerConfig.obstacle_weight', index=7,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_weight', full_name='apollo.planning.DpStSpeedOptimizerConfig.reference_weight', index=8,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go_down_buffer', full_name='apollo.planning.DpStSpeedOptimizerConfig.go_down_buffer', index=9,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go_up_buffer', full_name='apollo.planning.DpStSpeedOptimizerConfig.go_up_buffer', index=10,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_obstacle_cost', full_name='apollo.planning.DpStSpeedOptimizerConfig.default_obstacle_cost', index=11,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000000000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_speed_cost', full_name='apollo.planning.DpStSpeedOptimizerConfig.default_speed_cost', index=12,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exceed_speed_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.exceed_speed_penalty', index=13,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_speed_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.low_speed_penalty', index=14,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_speed_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.reference_speed_penalty', index=15,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_clear_low_speed_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.keep_clear_low_speed_penalty', index=16,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.accel_penalty', index=17,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decel_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.decel_penalty', index=18,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_jerk_coeff', full_name='apollo.planning.DpStSpeedOptimizerConfig.positive_jerk_coeff', index=19,
      number=50, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_jerk_coeff', full_name='apollo.planning.DpStSpeedOptimizerConfig.negative_jerk_coeff', index=20,
      number=51, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(300),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='apollo.planning.DpStSpeedOptimizerConfig.max_acceleration', index=21,
      number=60, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deceleration', full_name='apollo.planning.DpStSpeedOptimizerConfig.max_deceleration', index=22,
      number=61, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(-4.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_time_buffer', full_name='apollo.planning.DpStSpeedOptimizerConfig.safe_time_buffer', index=23,
      number=70, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safe_distance', full_name='apollo.planning.DpStSpeedOptimizerConfig.safe_distance', index=24,
      number=71, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(20),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spatial_potential_penalty', full_name='apollo.planning.DpStSpeedOptimizerConfig.spatial_potential_penalty', index=25,
      number=80, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_lane_changing', full_name='apollo.planning.DpStSpeedOptimizerConfig.is_lane_changing', index=26,
      number=81, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5006,
  serialized_end=5847,
)


_STBOUNDSDECIDERCONFIG = _descriptor.Descriptor(
  name='STBoundsDeciderConfig',
  full_name='apollo.planning.STBoundsDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time', full_name='apollo.planning.STBoundsDeciderConfig.total_time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5849,
  serialized_end=5895,
)

_LEARNINGMODELINFERENCETASKCONFIG.fields_by_name['model_type'].enum_type = _LEARNINGMODELINFERENCETASKCONFIG_MODELTYPE
_LEARNINGMODELINFERENCETASKCONFIG_MODELTYPE.containing_type = _LEARNINGMODELINFERENCETASKCONFIG
_NAVIPATHDECIDERCONFIG.fields_by_name['move_dest_lane_config_talbe'].message_type = _MOVEDESTLANECONFIGTABLE
_MOVEDESTLANECONFIGTABLE.fields_by_name['lateral_shift'].message_type = _SHIFTCONFIG
_PIECEWISEJERKPATHOPTIMIZERCONFIG.fields_by_name['default_path_config'].message_type = _PIECEWISEJERKPATHWEIGHTS
_PIECEWISEJERKPATHOPTIMIZERCONFIG.fields_by_name['lane_change_path_config'].message_type = _PIECEWISEJERKPATHWEIGHTS
_SPEEDHEURISTICOPTIMIZERCONFIG.fields_by_name['default_speed_config'].message_type = _DPSTSPEEDOPTIMIZERCONFIG
_SPEEDHEURISTICOPTIMIZERCONFIG.fields_by_name['lane_change_speed_config'].message_type = _DPSTSPEEDOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['CreepDeciderConfig'] = _CREEPDECIDERCONFIG
DESCRIPTOR.message_types_by_name['LaneChangeDeciderConfig'] = _LANECHANGEDECIDERCONFIG
DESCRIPTOR.message_types_by_name['LearningModelInferenceTaskConfig'] = _LEARNINGMODELINFERENCETASKCONFIG
DESCRIPTOR.message_types_by_name['LearningModelInferenceTrajectoryTaskConfig'] = _LEARNINGMODELINFERENCETRAJECTORYTASKCONFIG
DESCRIPTOR.message_types_by_name['NaviObstacleDeciderConfig'] = _NAVIOBSTACLEDECIDERCONFIG
DESCRIPTOR.message_types_by_name['NaviPathDeciderConfig'] = _NAVIPATHDECIDERCONFIG
DESCRIPTOR.message_types_by_name['MoveDestLaneConfigTable'] = _MOVEDESTLANECONFIGTABLE
DESCRIPTOR.message_types_by_name['ShiftConfig'] = _SHIFTCONFIG
DESCRIPTOR.message_types_by_name['NaviSpeedDeciderConfig'] = _NAVISPEEDDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathAssessmentDeciderConfig'] = _PATHASSESSMENTDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathBoundsDeciderConfig'] = _PATHBOUNDSDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathDeciderConfig'] = _PATHDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathLaneBorrowDeciderConfig'] = _PATHLANEBORROWDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathReferenceDeciderConfig'] = _PATHREFERENCEDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PathReuseDeciderConfig'] = _PATHREUSEDECIDERCONFIG
DESCRIPTOR.message_types_by_name['PiecewiseJerkNonlinearSpeedOptimizerConfig'] = _PIECEWISEJERKNONLINEARSPEEDOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['PiecewiseJerkPathOptimizerConfig'] = _PIECEWISEJERKPATHOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['PiecewiseJerkPathWeights'] = _PIECEWISEJERKPATHWEIGHTS
DESCRIPTOR.message_types_by_name['PiecewiseJerkSpeedOptimizerConfig'] = _PIECEWISEJERKSPEEDOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['RuleBasedStopDeciderConfig'] = _RULEBASEDSTOPDECIDERCONFIG
DESCRIPTOR.message_types_by_name['SpeedBoundsDeciderConfig'] = _SPEEDBOUNDSDECIDERCONFIG
DESCRIPTOR.message_types_by_name['SpeedHeuristicOptimizerConfig'] = _SPEEDHEURISTICOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['DpStSpeedOptimizerConfig'] = _DPSTSPEEDOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['STBoundsDeciderConfig'] = _STBOUNDSDECIDERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreepDeciderConfig = _reflection.GeneratedProtocolMessageType('CreepDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _CREEPDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CreepDeciderConfig)
  })
_sym_db.RegisterMessage(CreepDeciderConfig)

LaneChangeDeciderConfig = _reflection.GeneratedProtocolMessageType('LaneChangeDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _LANECHANGEDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LaneChangeDeciderConfig)
  })
_sym_db.RegisterMessage(LaneChangeDeciderConfig)

LearningModelInferenceTaskConfig = _reflection.GeneratedProtocolMessageType('LearningModelInferenceTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _LEARNINGMODELINFERENCETASKCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LearningModelInferenceTaskConfig)
  })
_sym_db.RegisterMessage(LearningModelInferenceTaskConfig)

LearningModelInferenceTrajectoryTaskConfig = _reflection.GeneratedProtocolMessageType('LearningModelInferenceTrajectoryTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _LEARNINGMODELINFERENCETRAJECTORYTASKCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LearningModelInferenceTrajectoryTaskConfig)
  })
_sym_db.RegisterMessage(LearningModelInferenceTrajectoryTaskConfig)

NaviObstacleDeciderConfig = _reflection.GeneratedProtocolMessageType('NaviObstacleDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVIOBSTACLEDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.NaviObstacleDeciderConfig)
  })
_sym_db.RegisterMessage(NaviObstacleDeciderConfig)

NaviPathDeciderConfig = _reflection.GeneratedProtocolMessageType('NaviPathDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVIPATHDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.NaviPathDeciderConfig)
  })
_sym_db.RegisterMessage(NaviPathDeciderConfig)

MoveDestLaneConfigTable = _reflection.GeneratedProtocolMessageType('MoveDestLaneConfigTable', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDESTLANECONFIGTABLE,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MoveDestLaneConfigTable)
  })
_sym_db.RegisterMessage(MoveDestLaneConfigTable)

ShiftConfig = _reflection.GeneratedProtocolMessageType('ShiftConfig', (_message.Message,), {
  'DESCRIPTOR' : _SHIFTCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ShiftConfig)
  })
_sym_db.RegisterMessage(ShiftConfig)

NaviSpeedDeciderConfig = _reflection.GeneratedProtocolMessageType('NaviSpeedDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVISPEEDDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.NaviSpeedDeciderConfig)
  })
_sym_db.RegisterMessage(NaviSpeedDeciderConfig)

PathAssessmentDeciderConfig = _reflection.GeneratedProtocolMessageType('PathAssessmentDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHASSESSMENTDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathAssessmentDeciderConfig)
  })
_sym_db.RegisterMessage(PathAssessmentDeciderConfig)

PathBoundsDeciderConfig = _reflection.GeneratedProtocolMessageType('PathBoundsDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHBOUNDSDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathBoundsDeciderConfig)
  })
_sym_db.RegisterMessage(PathBoundsDeciderConfig)

PathDeciderConfig = _reflection.GeneratedProtocolMessageType('PathDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathDeciderConfig)
  })
_sym_db.RegisterMessage(PathDeciderConfig)

PathLaneBorrowDeciderConfig = _reflection.GeneratedProtocolMessageType('PathLaneBorrowDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHLANEBORROWDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathLaneBorrowDeciderConfig)
  })
_sym_db.RegisterMessage(PathLaneBorrowDeciderConfig)

PathReferenceDeciderConfig = _reflection.GeneratedProtocolMessageType('PathReferenceDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHREFERENCEDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathReferenceDeciderConfig)
  })
_sym_db.RegisterMessage(PathReferenceDeciderConfig)

PathReuseDeciderConfig = _reflection.GeneratedProtocolMessageType('PathReuseDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _PATHREUSEDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathReuseDeciderConfig)
  })
_sym_db.RegisterMessage(PathReuseDeciderConfig)

PiecewiseJerkNonlinearSpeedOptimizerConfig = _reflection.GeneratedProtocolMessageType('PiecewiseJerkNonlinearSpeedOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _PIECEWISEJERKNONLINEARSPEEDOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfig)
  })
_sym_db.RegisterMessage(PiecewiseJerkNonlinearSpeedOptimizerConfig)

PiecewiseJerkPathOptimizerConfig = _reflection.GeneratedProtocolMessageType('PiecewiseJerkPathOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _PIECEWISEJERKPATHOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PiecewiseJerkPathOptimizerConfig)
  })
_sym_db.RegisterMessage(PiecewiseJerkPathOptimizerConfig)

PiecewiseJerkPathWeights = _reflection.GeneratedProtocolMessageType('PiecewiseJerkPathWeights', (_message.Message,), {
  'DESCRIPTOR' : _PIECEWISEJERKPATHWEIGHTS,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PiecewiseJerkPathWeights)
  })
_sym_db.RegisterMessage(PiecewiseJerkPathWeights)

PiecewiseJerkSpeedOptimizerConfig = _reflection.GeneratedProtocolMessageType('PiecewiseJerkSpeedOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _PIECEWISEJERKSPEEDOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PiecewiseJerkSpeedOptimizerConfig)
  })
_sym_db.RegisterMessage(PiecewiseJerkSpeedOptimizerConfig)

RuleBasedStopDeciderConfig = _reflection.GeneratedProtocolMessageType('RuleBasedStopDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _RULEBASEDSTOPDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.RuleBasedStopDeciderConfig)
  })
_sym_db.RegisterMessage(RuleBasedStopDeciderConfig)

SpeedBoundsDeciderConfig = _reflection.GeneratedProtocolMessageType('SpeedBoundsDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDBOUNDSDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SpeedBoundsDeciderConfig)
  })
_sym_db.RegisterMessage(SpeedBoundsDeciderConfig)

SpeedHeuristicOptimizerConfig = _reflection.GeneratedProtocolMessageType('SpeedHeuristicOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDHEURISTICOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SpeedHeuristicOptimizerConfig)
  })
_sym_db.RegisterMessage(SpeedHeuristicOptimizerConfig)

DpStSpeedOptimizerConfig = _reflection.GeneratedProtocolMessageType('DpStSpeedOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DPSTSPEEDOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DpStSpeedOptimizerConfig)
  })
_sym_db.RegisterMessage(DpStSpeedOptimizerConfig)

STBoundsDeciderConfig = _reflection.GeneratedProtocolMessageType('STBoundsDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _STBOUNDSDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.STBoundsDeciderConfig)
  })
_sym_db.RegisterMessage(STBoundsDeciderConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/traffic_light_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/traffic_light_detection.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6modules/perception/proto/traffic_light_detection.proto\x12\x11\x61pollo.perception\x1a!modules/common/proto/header.proto\"\xa3\x01\n\x0fTrafficLightBox\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x34\n\x05\x63olor\x18\x05 \x01(\x0e\x32%.apollo.perception.TrafficLight.Color\x12\x10\n\x08selected\x18\x06 \x01(\x08\x12\x13\n\x0b\x63\x61mera_name\x18\x07 \x01(\t\"\xfa\x03\n\x11TrafficLightDebug\x12\x33\n\x07\x63ropbox\x18\x01 \x01(\x0b\x32\".apollo.perception.TrafficLightBox\x12/\n\x03\x62ox\x18\x02 \x03(\x0b\x32\".apollo.perception.TrafficLightBox\x12\x12\n\nsignal_num\x18\x03 \x01(\x05\x12\x11\n\tvalid_pos\x18\x04 \x01(\x05\x12\x13\n\x0bts_diff_pos\x18\x05 \x01(\x01\x12\x13\n\x0bts_diff_sys\x18\x06 \x01(\x01\x12\x15\n\rproject_error\x18\x07 \x01(\x05\x12\x1d\n\x15\x64istance_to_stop_line\x18\x08 \x01(\x01\x12\x15\n\tcamera_id\x18\t \x01(\x05\x42\x02\x18\x01\x12\x34\n\x08\x63rop_roi\x18\n \x03(\x0b\x32\".apollo.perception.TrafficLightBox\x12\x39\n\rprojected_roi\x18\x0b \x03(\x0b\x32\".apollo.perception.TrafficLightBox\x12\x39\n\rrectified_roi\x18\x0c \x03(\x0b\x32\".apollo.perception.TrafficLightBox\x12\x35\n\tdebug_roi\x18\r \x03(\x0b\x32\".apollo.perception.TrafficLightBox\"\xe6\x01\n\x0cTrafficLight\x12\x34\n\x05\x63olor\x18\x01 \x01(\x0e\x32%.apollo.perception.TrafficLight.Color\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\nconfidence\x18\x03 \x01(\x01:\x01\x31\x12\x15\n\rtracking_time\x18\x04 \x01(\x01\x12\r\n\x05\x62link\x18\x05 \x01(\x08\x12\x16\n\x0eremaining_time\x18\x06 \x01(\x01\"?\n\x05\x43olor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03RED\x10\x01\x12\n\n\x06YELLOW\x10\x02\x12\t\n\x05GREEN\x10\x03\x12\t\n\x05\x42LACK\x10\x04\"\x82\x03\n\x15TrafficLightDetection\x12%\n\x06header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header\x12\x36\n\rtraffic_light\x18\x01 \x03(\x0b\x32\x1f.apollo.perception.TrafficLight\x12\x41\n\x13traffic_light_debug\x18\x03 \x01(\x0b\x32$.apollo.perception.TrafficLightDebug\x12\x16\n\x0e\x63ontain_lights\x18\x04 \x01(\x08\x12\x44\n\tcamera_id\x18\x05 \x01(\x0e\x32\x31.apollo.perception.TrafficLightDetection.CameraID\"i\n\x08\x43\x61meraID\x12\x15\n\x11\x43\x41MERA_FRONT_LONG\x10\x00\x12\x17\n\x13\x43\x41MERA_FRONT_NARROW\x10\x01\x12\x16\n\x12\x43\x41MERA_FRONT_SHORT\x10\x02\x12\x15\n\x11\x43\x41MERA_FRONT_WIDE\x10\x03'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])



_TRAFFICLIGHT_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='apollo.perception.TrafficLight.Color',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLACK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=955,
  serialized_end=1018,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICLIGHT_COLOR)

_TRAFFICLIGHTDETECTION_CAMERAID = _descriptor.EnumDescriptor(
  name='CameraID',
  full_name='apollo.perception.TrafficLightDetection.CameraID',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAMERA_FRONT_LONG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_FRONT_NARROW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_FRONT_SHORT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_FRONT_WIDE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1302,
  serialized_end=1407,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICLIGHTDETECTION_CAMERAID)


_TRAFFICLIGHTBOX = _descriptor.Descriptor(
  name='TrafficLightBox',
  full_name='apollo.perception.TrafficLightBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.perception.TrafficLightBox.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.perception.TrafficLightBox.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.perception.TrafficLightBox.width', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.perception.TrafficLightBox.height', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.perception.TrafficLightBox.color', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected', full_name='apollo.perception.TrafficLightBox.selected', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_name', full_name='apollo.perception.TrafficLightBox.camera_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=276,
)


_TRAFFICLIGHTDEBUG = _descriptor.Descriptor(
  name='TrafficLightDebug',
  full_name='apollo.perception.TrafficLightDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cropbox', full_name='apollo.perception.TrafficLightDebug.cropbox', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box', full_name='apollo.perception.TrafficLightDebug.box', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_num', full_name='apollo.perception.TrafficLightDebug.signal_num', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_pos', full_name='apollo.perception.TrafficLightDebug.valid_pos', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_diff_pos', full_name='apollo.perception.TrafficLightDebug.ts_diff_pos', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_diff_sys', full_name='apollo.perception.TrafficLightDebug.ts_diff_sys', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_error', full_name='apollo.perception.TrafficLightDebug.project_error', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_to_stop_line', full_name='apollo.perception.TrafficLightDebug.distance_to_stop_line', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='apollo.perception.TrafficLightDebug.camera_id', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crop_roi', full_name='apollo.perception.TrafficLightDebug.crop_roi', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projected_roi', full_name='apollo.perception.TrafficLightDebug.projected_roi', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rectified_roi', full_name='apollo.perception.TrafficLightDebug.rectified_roi', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_roi', full_name='apollo.perception.TrafficLightDebug.debug_roi', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=785,
)


_TRAFFICLIGHT = _descriptor.Descriptor(
  name='TrafficLight',
  full_name='apollo.perception.TrafficLight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.perception.TrafficLight.color', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.perception.TrafficLight.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.perception.TrafficLight.confidence', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.perception.TrafficLight.tracking_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blink', full_name='apollo.perception.TrafficLight.blink', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remaining_time', full_name='apollo.perception.TrafficLight.remaining_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICLIGHT_COLOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=1018,
)


_TRAFFICLIGHTDETECTION = _descriptor.Descriptor(
  name='TrafficLightDetection',
  full_name='apollo.perception.TrafficLightDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.TrafficLightDetection.header', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='apollo.perception.TrafficLightDetection.traffic_light', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_debug', full_name='apollo.perception.TrafficLightDetection.traffic_light_debug', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contain_lights', full_name='apollo.perception.TrafficLightDetection.contain_lights', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='apollo.perception.TrafficLightDetection.camera_id', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICLIGHTDETECTION_CAMERAID,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1407,
)

_TRAFFICLIGHTBOX.fields_by_name['color'].enum_type = _TRAFFICLIGHT_COLOR
_TRAFFICLIGHTDEBUG.fields_by_name['cropbox'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHTDEBUG.fields_by_name['box'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHTDEBUG.fields_by_name['crop_roi'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHTDEBUG.fields_by_name['projected_roi'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHTDEBUG.fields_by_name['rectified_roi'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHTDEBUG.fields_by_name['debug_roi'].message_type = _TRAFFICLIGHTBOX
_TRAFFICLIGHT.fields_by_name['color'].enum_type = _TRAFFICLIGHT_COLOR
_TRAFFICLIGHT_COLOR.containing_type = _TRAFFICLIGHT
_TRAFFICLIGHTDETECTION.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_TRAFFICLIGHTDETECTION.fields_by_name['traffic_light'].message_type = _TRAFFICLIGHT
_TRAFFICLIGHTDETECTION.fields_by_name['traffic_light_debug'].message_type = _TRAFFICLIGHTDEBUG
_TRAFFICLIGHTDETECTION.fields_by_name['camera_id'].enum_type = _TRAFFICLIGHTDETECTION_CAMERAID
_TRAFFICLIGHTDETECTION_CAMERAID.containing_type = _TRAFFICLIGHTDETECTION
DESCRIPTOR.message_types_by_name['TrafficLightBox'] = _TRAFFICLIGHTBOX
DESCRIPTOR.message_types_by_name['TrafficLightDebug'] = _TRAFFICLIGHTDEBUG
DESCRIPTOR.message_types_by_name['TrafficLight'] = _TRAFFICLIGHT
DESCRIPTOR.message_types_by_name['TrafficLightDetection'] = _TRAFFICLIGHTDETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrafficLightBox = _reflection.GeneratedProtocolMessageType('TrafficLightBox', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTBOX,
  '__module__' : 'modules.perception.proto.traffic_light_detection_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.TrafficLightBox)
  })
_sym_db.RegisterMessage(TrafficLightBox)

TrafficLightDebug = _reflection.GeneratedProtocolMessageType('TrafficLightDebug', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTDEBUG,
  '__module__' : 'modules.perception.proto.traffic_light_detection_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.TrafficLightDebug)
  })
_sym_db.RegisterMessage(TrafficLightDebug)

TrafficLight = _reflection.GeneratedProtocolMessageType('TrafficLight', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHT,
  '__module__' : 'modules.perception.proto.traffic_light_detection_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.TrafficLight)
  })
_sym_db.RegisterMessage(TrafficLight)

TrafficLightDetection = _reflection.GeneratedProtocolMessageType('TrafficLightDetection', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTDETECTION,
  '__module__' : 'modules.perception.proto.traffic_light_detection_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.TrafficLightDetection)
  })
_sym_db.RegisterMessage(TrafficLightDetection)


_TRAFFICLIGHTDEBUG.fields_by_name['camera_id']._options = None
# @@protoc_insertion_point(module_scope)
